package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class AttributeCertificate extends ASN1Encodable {
   AttributeCertificateInfo acinfo;
   AlgorithmIdentifier signatureAlgorithm;
   DERBitString signatureValue;

   public static AttributeCertificate getInstance(Object obj) {
      if (obj instanceof AttributeCertificate) {
         return (AttributeCertificate)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new AttributeCertificate((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public AttributeCertificate(AttributeCertificateInfo acinfo, AlgorithmIdentifier signatureAlgorithm, DERBitString signatureValue) {
      this.acinfo = acinfo;
      this.signatureAlgorithm = signatureAlgorithm;
      this.signatureValue = signatureValue;
   }

   public AttributeCertificate(ASN1Sequence seq) {
      if (seq.size() == 3) {
         this.acinfo = AttributeCertificateInfo.getInstance(seq.getObjectAt(0));
         this.signatureAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
         this.signatureValue = DERBitString.getInstance(seq.getObjectAt(2));
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public AttributeCertificateInfo getAcinfo() {
      return this.acinfo;
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      return this.signatureAlgorithm;
   }

   public DERBitString getSignatureValue() {
      return this.signatureValue;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.acinfo);
      var1.add(this.signatureAlgorithm);
      var10000.add(this.signatureValue);
      return new DERSequence(var1);
   }
}
